@@ -2,7 +2,13 @@ from .. import Provider as AutomotiveProvider
 
 
 class Provider(AutomotiveProvider):
-    # See https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_New_Zealand
+    """Implement automotive provider for ``en_NZ`` locale.
+
+    Sources:
+
+    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_New_Zealand
+    """
+
     license_formats = (
         # Old plates
         '??%##',
